require "time"
require "date"
require 'google_calendar'
require 'addressable/uri'

module Ruboty
  module Gcal
    class Calendar
      def initialize
        @calendar ||= Google::Calendar.new({
          username: ENV["GCAL_USERNAME"],
          password: ENV["GCAL_PASSWORD"],
          app_name: ENV["GCAL_APP_NAME"]
        })
      end

      def today
        today = Time.now.utc
        tomorrow = today + 86400
        @calendar.find_events_in_range(today, tomorrow) || "Event Not Found"
      end

      def recent
        events = @calendar.find_future_events({max_results: 5})
        events.map { |e| e.to_s }.join("\n") || "Event Not Found"
      end

      def find(message)
        #Support Japanese
        q = Addressable::URI.parse(message[:query]).normalize.to_s
        message.reply(@calendar.find_events(q) || "Event Not Found")
      end

      def schedule(message)
        event = @calendar.create_event { |e|
          e.title = message[:title]
          e.start_time = Time.parse(message[:start_time])
          e.end_time = Time.parse(message[:end_time])
        }
        message.reply("Scheduled #{event}")
      rescue ArgumentError
        message.reply("Could not schedule the event")
      end

      def unschedule(message)
        if event = @calendar.find_event_by_id(message[:event_id])
          @calendar.delete_event(event)
          message.reply("Deleted #{event.title}")
        else
          message.reply("Event Not Found")
        end
      end
    end
  end
end
